@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2012-2016 Maarten Baert <maarten-baert@hotmail.com>
+Copyright (c) 2012-2017 Maarten Baert <maarten-baert@hotmail.com>
 
 This file is part of SimpleScreenRecorder.
 
@@ -17,7 +17,6 @@ You should have received a copy of the GNU General Public License
 along with SimpleScreenRecorder.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Global.h"
 #include "Synchronizer.h"
 
 #include "Main.h"
@@ -111,8 +110,9 @@ static std::unique_ptr<AVFrameWrapper> CreateVideoFrame(unsigned int width, unsi
 			linesize[0] = grow_align16(width * 4); planesize[0] = linesize[0] * height;
 			break;
 		}
-		case AV_PIX_FMT_BGR24: {
-			// BGR = 3 bytes per pixel
+		case AV_PIX_FMT_BGR24:
+		case AV_PIX_FMT_RGB24: {
+			// BGR/RGB = 3 bytes per pixel
 			planes = 1;
 			linesize[0] = grow_align16(width * 3); planesize[0] = linesize[0] * height;
 			break;
