@@ -20,6 +20,8 @@ along with SimpleScreenRecorder.  If not, see <http://www.gnu.org/licenses/>.
 #pragma once
 #include "Global.h"
 
+#if SSR_USE_OPENGL_RECORDING
+
 class SSRVideoStream;
 class SSRVideoStreamWatcher;
 
@@ -48,3 +50,5 @@ private slots:
 	void OnLaunchNow();
 
 };
+
+#endif
