@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2012-2016 Maarten Baert <maarten-baert@hotmail.com>
+Copyright (c) 2012-2017 Maarten Baert <maarten-baert@hotmail.com>
 
 This file is part of SimpleScreenRecorder.
 
@@ -35,7 +35,9 @@ along with SimpleScreenRecorder.  If not, see <http://www.gnu.org/licenses/>.
 #include "Synchronizer.h"
 #include "X11Input.h"
 #include "GLInjectInput.h"
+#if SSR_USE_ALSA
 #include "ALSAInput.h"
+#endif
 #if SSR_USE_PULSEAUDIO
 #include "PulseAudioInput.h"
 #endif
@@ -49,14 +51,20 @@ along with SimpleScreenRecorder.  If not, see <http://www.gnu.org/licenses/>.
 #include <X11/keysym.h>
 #include <X11/keysymdef.h>
 
-static QString GetNewSegmentFile(const QString& file) {
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+
+static QString GetNewSegmentFile(const QString& file, bool add_timestamp) {
 	QFileInfo fi(file);
 	QDateTime now = QDateTime::currentDateTime();
 	QString newfile;
 	unsigned int counter = 0;
 	do {
 		++counter;
-		newfile = fi.path() + "/" + fi.completeBaseName() + "-" + now.toString("yyyy-MM-dd_hh.mm.ss");
+		newfile = fi.path() + "/" + fi.completeBaseName();
+		if(add_timestamp)
+			newfile += "-" + now.toString("yyyy-MM-dd_hh.mm.ss");
 		if(counter != 1)
 			newfile += "-(" + QString::number(counter) + ")";
 		if(!fi.suffix().isEmpty())
@@ -80,14 +88,24 @@ static std::vector<std::pair<QString, QString> > GetOptionsFromString(const QStr
 	return options;
 }
 
-static QString ReadableSize(uint64_t size, const QString& suffix) {
+static QString ReadableSizeIEC(uint64_t size, const QString& suffix) {
 	if(size < (uint64_t) 10 * 1024)
 		return QString::number(size) + " " + suffix;
 	if(size < (uint64_t) 10 * 1024 * 1024)
-		return QString::number((size + 512) / 1024) + " k" + suffix;
+		return QString::number((size + 512) / 1024) + " Ki" + suffix;
 	if(size < (uint64_t) 10 * 1024 * 1024 * 1024)
-		return QString::number((size / 1024 + 512) / 1024) + " M" + suffix;
-	return QString::number((size / 1024 / 1024 + 512) / 1024) + " G" + suffix;
+		return QString::number((size / 1024 + 512) / 1024) + " Mi" + suffix;
+	return QString::number((size / (1024 * 1024) + 512) / 1024) + " Gi" + suffix;
+}
+
+static QString ReadableSizeSI(uint64_t size, const QString& suffix) {
+	if(size < (uint64_t) 10 * 1000)
+		return QString::number(size) + " " + suffix;
+	if(size < (uint64_t) 10 * 1000 * 1000)
+		return QString::number((size + 500) / 1000) + " k" + suffix;
+	if(size < (uint64_t) 10 * 1000 * 1000 * 1000)
+		return QString::number((size / 1000 + 500) / 1000) + " M" + suffix;
+	return QString::number((size / (1000 * 1000) + 512) / 1024) + " G" + suffix;
 }
 
 static QString ReadableTime(int64_t time_micro) {
@@ -114,6 +132,7 @@ public:
 };
 
 // sound notification sequences
+#if SSR_USE_ALSA
 static const std::array<SimpleSynth::Note, 1> SEQUENCE_RECORD_START = {{
 	{0    , 500, 10000, 440.0f * exp2f( 3.0f / 12.0f), 0.8f}, // C5
 }};
@@ -127,6 +146,7 @@ static const std::array<SimpleSynth::Note, 4> SEQUENCE_RECORD_ERROR = {{
 	{20000, 500, 20000, 440.0f * exp2f(-6.0f / 12.0f), 0.4f}, // D#4
 	{20000, 500, 20000, 440.0f * exp2f(-9.0f / 12.0f), 0.6f}, // C4
 }};
+#endif
 
 const int PageRecord::PRIORITY_RECORD = 0;
 const int PageRecord::PRIORITY_PREVIEW = -1;
@@ -141,14 +161,18 @@ PageRecord::PageRecord(MainWindow* main_window)
 	m_output_started = false;
 	m_previewing = false;
 
+#if SSR_USE_ALSA
 	m_last_error_sound = std::numeric_limits<int64_t>::min();
+#endif
 
 	QGroupBox *groupbox_recording = new QGroupBox(tr("Recording"), this);
 	{
 		m_pushbutton_start_pause = new QPushButton(groupbox_recording);
 
 		m_checkbox_hotkey_enable = new QCheckBox(tr("Enable recording hotkey"), groupbox_recording);
+#if SSR_USE_ALSA
 		m_checkbox_sound_notifications_enable = new QCheckBox(tr("Enable sound notifications"), groupbox_recording);
+#endif
 		QLabel *label_hotkey = new QLabel(tr("Hotkey:"), groupbox_recording);
 		m_checkbox_hotkey_ctrl = new QCheckBox(tr("Ctrl +"), groupbox_recording);
 		m_checkbox_hotkey_shift = new QCheckBox(tr("Shift +"), groupbox_recording);
@@ -165,7 +189,9 @@ PageRecord::PageRecord(MainWindow* main_window)
 
 		connect(m_pushbutton_start_pause, SIGNAL(clicked()), this, SLOT(OnRecordStartPause()));
 		connect(m_checkbox_hotkey_enable, SIGNAL(clicked()), this, SLOT(OnUpdateHotkeyFields()));
+#if SSR_USE_ALSA
 		connect(m_checkbox_sound_notifications_enable, SIGNAL(clicked()), this, SLOT(OnUpdateSoundNotifications()));
+#endif
 		connect(m_checkbox_hotkey_ctrl, SIGNAL(clicked()), this, SLOT(OnUpdateHotkey()));
 		connect(m_checkbox_hotkey_shift, SIGNAL(clicked()), this, SLOT(OnUpdateHotkey()));
 		connect(m_checkbox_hotkey_alt, SIGNAL(clicked()), this, SLOT(OnUpdateHotkey()));
@@ -178,7 +204,9 @@ PageRecord::PageRecord(MainWindow* main_window)
 			QHBoxLayout *layout2 = new QHBoxLayout();
 			layout->addLayout(layout2);
 			layout2->addWidget(m_checkbox_hotkey_enable);
+#if SSR_USE_ALSA
 			layout2->addWidget(m_checkbox_sound_notifications_enable);
+#endif
 		}
 		{
 			QHBoxLayout *layout2 = new QHBoxLayout();
@@ -311,7 +339,7 @@ PageRecord::PageRecord(MainWindow* main_window)
 	QPushButton *button_save = new QPushButton(g_icon_save, tr("Save recording"), this);
 
 	if(g_option_systray) {
-		m_systray_icon = new QSystemTrayIcon(g_icon_ssr, m_main_window);
+		m_systray_icon = new QSystemTrayIcon(g_icon_ssr_idle, m_main_window);
 		QMenu *menu = new QMenu(m_main_window);
 		m_systray_action_start_pause = menu->addAction(QString(), this, SLOT(OnRecordStartPause()));
 		m_systray_action_start_pause->setIconVisibleInMenu(true);
@@ -390,10 +418,14 @@ void PageRecord::LoadSettings(QSettings *settings) {
 	SetHotkeyAltEnabled(settings->value("record/hotkey_alt", false).toBool());
 	SetHotkeySuperEnabled(settings->value("record/hotkey_super", false).toBool());
 	SetHotkeyKey(settings->value("record/hotkey_key", 'r' - 'a').toUInt());
+#if SSR_USE_ALSA
 	SetSoundNotificationsEnabled(settings->value("record/sound_notifications_enable", false).toBool());
+#endif
 	SetPreviewFrameRate(settings->value("record/preview_frame_rate", 10).toUInt());
 	OnUpdateHotkeyFields();
+#if SSR_USE_ALSA
 	OnUpdateSoundNotifications();
+#endif
 }
 
 void PageRecord::SaveSettings(QSettings *settings) {
@@ -403,7 +435,9 @@ void PageRecord::SaveSettings(QSettings *settings) {
 	settings->setValue("record/hotkey_alt", IsHotkeyAltEnabled());
 	settings->setValue("record/hotkey_super", IsHotkeySuperEnabled());
 	settings->setValue("record/hotkey_key", GetHotkeyKey());
+#if SSR_USE_ALSA
 	settings->setValue("record/sound_notifications_enable", AreSoundNotificationsEnabled());
+#endif
 	settings->setValue("record/preview_frame_rate", GetPreviewFrameRate());
 }
 
@@ -444,13 +478,19 @@ void PageRecord::StartPage() {
 	m_video_area = page_input->GetVideoArea();
 	m_video_x = page_input->GetVideoX();
 	m_video_y = page_input->GetVideoY();
+#if SSR_USE_OPENGL_RECORDING
 	if(m_video_area == PageInput::VIDEO_AREA_GLINJECT) {
 		m_video_in_width = 0;
 		m_video_in_height = 0;
 	} else {
+#else
+	{
+#endif
 		m_video_in_width = page_input->GetVideoW();
 		m_video_in_height = page_input->GetVideoH();
 	}
+	m_video_in_width = page_input->GetVideoW();
+	m_video_in_height = page_input->GetVideoH();
 	m_video_frame_rate = page_input->GetVideoFrameRate();
 	m_video_scaling = page_input->GetVideoScalingEnabled();
 	m_video_scaled_width = page_input->GetVideoScaledW();
@@ -462,7 +502,9 @@ void PageRecord::StartPage() {
 	m_audio_channels = 2;
 	m_audio_sample_rate = 48000;
 	m_audio_backend = page_input->GetAudioBackend();
+#if SSR_USE_ALSA
 	m_alsa_source = page_input->GetALSASourceName();
+#endif
 #if SSR_USE_PULSEAUDIO
 	m_pulseaudio_source = page_input->GetPulseAudioSourceName();
 #endif
@@ -476,6 +518,7 @@ void PageRecord::StartPage() {
 		m_audio_sample_rate = 44100;
 	}
 
+#if SSR_USE_OPENGL_RECORDING
 	// get the glinject settings
 	QString glinject_channel = page_input->GetGLInjectChannel();
 	bool glinject_relax_permissions = page_input->GetGLInjectRelaxPermissions();
@@ -483,17 +526,16 @@ void PageRecord::StartPage() {
 	QString glinject_working_directory = page_input->GetGLInjectWorkingDirectory();
 	bool glinject_auto_launch = page_input->GetGLInjectAutoLaunch();
 	bool glinject_limit_fps = page_input->GetGLInjectLimitFPS();
+#endif
 
 	// get file settings
 	m_file_base = page_output->GetFile();
 	m_file_protocol = page_output->GetFileProtocol();
 	m_separate_files = page_output->GetSeparateFiles();
+	m_add_timestamp = page_output->GetAddTimestamp();
 
 	// get the output settings
-	if(m_separate_files)
-		m_output_settings.file = QString(); // will be set later
-	else
-		m_output_settings.file = m_file_base;
+	m_output_settings.file = QString(); // will be set later
 	m_output_settings.container_avname = page_output->GetContainerAVName();
 
 	m_output_settings.video_codec_avname = page_output->GetVideoCodecAVName();
@@ -552,12 +594,14 @@ void PageRecord::StartPage() {
 
 	try {
 
+#if SSR_USE_OPENGL_RECORDING
 		// for OpenGL recording, create the input now
 		if(m_video_area == PageInput::VIDEO_AREA_GLINJECT) {
 			if(glinject_auto_launch)
 				GLInjectInput::LaunchApplication(glinject_channel, glinject_relax_permissions, glinject_command, glinject_working_directory);
 			m_gl_inject_input.reset(new GLInjectInput(glinject_channel, glinject_relax_permissions, m_video_record_cursor, glinject_limit_fps, m_video_frame_rate));
 		}
+#endif
 
 #if SSR_USE_JACK
 		if(m_audio_enabled) {
@@ -569,7 +613,9 @@ void PageRecord::StartPage() {
 
 	} catch(...) {
 		Logger::LogError("[PageRecord::StartPage] " + tr("Error: Something went wrong during initialization."));
+#if SSR_USE_OPENGL_RECORDING
 		m_gl_inject_input.reset();
+#endif
 #if SSR_USE_JACK
 		m_jack_input.reset();
 #endif
@@ -582,7 +628,9 @@ void PageRecord::StartPage() {
 	m_wait_saving = false;
 	m_error_occurred = false;
 	UpdateSysTray();
+#if SSR_USE_ALSA
 	OnUpdateSoundNotifications();
+#endif
 
 	UpdateInput();
 
@@ -616,11 +664,13 @@ void PageRecord::StopPage(bool save) {
 
 	}
 
-	// destroy the GLInject input
+#if SSR_USE_OPENGL_RECORDING
+	// stop GLInject input
 	m_gl_inject_input.reset();
+#endif
 
-	// stop JACK input
 #if SSR_USE_JACK
+	// stop JACK input
 	m_jack_input.reset();
 #endif
 
@@ -628,7 +678,9 @@ void PageRecord::StopPage(bool save) {
 
 	m_page_started = false;
 	UpdateSysTray();
+#if SSR_USE_ALSA
 	OnUpdateSoundNotifications();
+#endif
 
 	m_timer_update_info->stop();
 	OnUpdateInformation();
@@ -641,10 +693,12 @@ void PageRecord::StartOutput() {
 	if(m_output_started)
 		return;
 
+#if SSR_USE_ALSA
 	if(m_simple_synth != NULL) {
 		m_simple_synth->PlaySequence(SEQUENCE_RECORD_START.data(), SEQUENCE_RECORD_START.size());
 		usleep(200000);
 	}
+#endif
 
 	try {
 
@@ -653,9 +707,9 @@ void PageRecord::StartOutput() {
 		if(m_output_manager == NULL) {
 
 			// set the file name
-			if(m_separate_files)
-				m_output_settings.file = GetNewSegmentFile(m_file_base);
+			m_output_settings.file = GetNewSegmentFile(m_file_base, m_add_timestamp);
 
+#if SSR_USE_OPENGL_RECORDING
 			// for OpenGL recording, detect the application size
 			if(m_video_area == PageInput::VIDEO_AREA_GLINJECT && !m_video_scaling) {
 				if(m_gl_inject_input == NULL) {
@@ -671,16 +725,19 @@ void PageRecord::StartOutput() {
 					throw GLInjectException();
 				}
 			}
+#endif
 
 			// calculate the output width and height
 			if(m_video_scaling) {
-				// Only even width and height is allowed because the final images are encoded as YUV.
+				// Only even width and height is allowed because some pixel formats (e.g. YUV420) require this.
 				m_output_settings.video_width = m_video_scaled_width / 2 * 2;
 				m_output_settings.video_height = m_video_scaled_height / 2 * 2;
+#if SSR_USE_OPENGL_RECORDING
 			} else if(m_video_area == PageInput::VIDEO_AREA_GLINJECT) {
 				// The input size is the size of the OpenGL application and can't be changed. The output size is set to the current size of the application.
 				m_output_settings.video_width = m_video_in_width / 2 * 2;
 				m_output_settings.video_height = m_video_in_height / 2 * 2;
+#endif
 			} else {
 				// If the user did not explicitly select scaling, then don't force scaling just because the recording area is one pixel too large.
 				// One missing row/column of pixels is probably better than a blurry video (and scaling is SLOW).
@@ -740,9 +797,11 @@ void PageRecord::StopOutput(bool final) {
 
 	Logger::LogInfo("[PageRecord::StopOutput] " + tr("Stopped output."));
 
+#if SSR_USE_ALSA
 	// if final, don't play the notification (it would get interrupted anyway)
 	if(m_simple_synth != NULL && !final)
 		m_simple_synth->PlaySequence(SEQUENCE_RECORD_STOP.data(), SEQUENCE_RECORD_STOP.size());
+#endif
 
 	m_output_started = false;
 	UpdateSysTray();
@@ -758,7 +817,9 @@ void PageRecord::StartInput() {
 		return;
 
 	assert(m_x11_input == NULL);
+#if SSR_USE_ALSA
 	assert(m_alsa_input == NULL);
+#endif
 #if SSR_USE_PULSEAUDIO
 	assert(m_pulseaudio_input == NULL);
 #endif
@@ -768,6 +829,7 @@ void PageRecord::StartInput() {
 		Logger::LogInfo("[PageRecord::StartInput] " + tr("Starting input ..."));
 
 		// start the video input
+#if SSR_USE_OPENGL_RECORDING
 		if(m_video_area == PageInput::VIDEO_AREA_GLINJECT) {
 			if(m_gl_inject_input == NULL) {
 				Logger::LogError("[PageRecord::StartInput] " + tr("Error: Could not start the GLInject input because it has not been created."));
@@ -775,13 +837,18 @@ void PageRecord::StartInput() {
 			}
 			m_gl_inject_input->SetCapturing(true);
 		} else {
+#else
+		{
+#endif
 			m_x11_input.reset(new X11Input(m_video_x, m_video_y, m_video_in_width, m_video_in_height, m_video_record_cursor, m_video_area == PageInput::VIDEO_AREA_CURSOR));
 		}
 
 		// start the audio input
 		if(m_audio_enabled) {
+#if SSR_USE_ALSA
 			if(m_audio_backend == PageInput::AUDIO_BACKEND_ALSA)
 				m_alsa_input.reset(new ALSAInput(m_alsa_source, m_audio_sample_rate));
+#endif
 #if SSR_USE_PULSEAUDIO
 			if(m_audio_backend == PageInput::AUDIO_BACKEND_PULSEAUDIO)
 				m_pulseaudio_input.reset(new PulseAudioInput(m_pulseaudio_source, m_audio_sample_rate));
@@ -796,9 +863,13 @@ void PageRecord::StartInput() {
 	} catch(...) {
 		Logger::LogError("[PageRecord::StartInput] " + tr("Error: Something went wrong during initialization."));
 		m_x11_input.reset();
+#if SSR_USE_OPENGL_RECORDING
 		if(m_gl_inject_input != NULL)
 			m_gl_inject_input->SetCapturing(false);
+#endif
+#if SSR_USE_ALSA
 		m_alsa_input.reset();
+#endif
 #if SSR_USE_PULSEAUDIO
 		m_pulseaudio_input.reset();
 #endif
@@ -817,9 +888,13 @@ void PageRecord::StopInput() {
 	Logger::LogInfo("[PageRecord::StopInput] " + tr("Stopping input ..."));
 
 	m_x11_input.reset();
+#if SSR_USE_OPENGL_RECORDING
 	if(m_gl_inject_input != NULL)
 		m_gl_inject_input->SetCapturing(false);
+#endif
+#if SSR_USE_ALSA
 	m_alsa_input.reset();
+#endif
 #if SSR_USE_PULSEAUDIO
 	m_pulseaudio_input.reset();
 #endif
@@ -873,14 +948,20 @@ void PageRecord::UpdateInput() {
 	// get sources
 	VideoSource *video_source = NULL;
 	AudioSource *audio_source = NULL;
+#if SSR_USE_OPENGL_RECORDING
 	if(m_video_area == PageInput::VIDEO_AREA_GLINJECT) {
 		video_source = m_gl_inject_input.get();
 	} else {
+#else
+	{
+#endif
 		video_source = m_x11_input.get();
 	}
 	if(m_audio_enabled) {
+#if SSR_USE_ALSA
 		if(m_audio_backend == PageInput::AUDIO_BACKEND_ALSA)
 			audio_source = m_alsa_input.get();
+#endif
 #if SSR_USE_PULSEAUDIO
 		if(m_audio_backend == PageInput::AUDIO_BACKEND_PULSEAUDIO)
 			audio_source = m_pulseaudio_input.get();
@@ -924,7 +1005,7 @@ void PageRecord::UpdateSysTray() {
 			m_systray_icon->setIcon(g_icon_ssr_paused);
 		}
 	} else {
-		m_systray_icon->setIcon(g_icon_ssr);
+		m_systray_icon->setIcon(g_icon_ssr_idle);
 	}
 	if(m_page_started && m_output_started) {
 		m_systray_action_start_pause->setIcon(g_icon_pause);
@@ -975,6 +1056,7 @@ void PageRecord::OnUpdateHotkey() {
 	}
 }
 
+#if SSR_USE_ALSA
 void PageRecord::OnUpdateSoundNotifications() {
 	if(m_page_started && AreSoundNotificationsEnabled()) {
 		if(m_simple_synth == NULL) {
@@ -988,6 +1070,7 @@ void PageRecord::OnUpdateSoundNotifications() {
 		m_simple_synth.reset();
 	}
 }
+#endif
 
 void PageRecord::OnRecordStartPause() {
 	if(QApplication::activeModalWidget() != NULL || QApplication::activePopupWidget() != NULL)
@@ -1055,11 +1138,12 @@ void PageRecord::OnUpdateInformation() {
 		double fps_out = 0.0;
 		uint64_t bit_rate = 0, total_bytes = 0;
 
-		if(m_gl_inject_input != NULL) {
+#if SSR_USE_OPENGL_RECORDING
+		if(m_gl_inject_input != NULL)
 			fps_in = m_gl_inject_input->GetFPS();
-		} else if(m_x11_input != NULL) {
+#endif
+		if(m_x11_input != NULL)
 			fps_in = m_x11_input->GetFPS();
-		}
 
 		if(m_output_manager != NULL) {
 			total_time = (m_output_manager->GetSynchronizer() == NULL)? 0 : m_output_manager->GetSynchronizer()->GetTotalTime();
@@ -1074,10 +1158,11 @@ void PageRecord::OnUpdateInformation() {
 		else
 			file_name = "(" + m_file_protocol + ")";
 
+#if SSR_USE_OPENGL_RECORDING
 		// for OpenGL recording, update the application size
-		if(m_gl_inject_input != NULL) {
+		if(m_gl_inject_input != NULL)
 			m_gl_inject_input->GetCurrentSize(&m_video_in_width, &m_video_in_height);
-		}
+#endif
 
 		m_label_info_total_time->setText(ReadableTime(total_time));
 		m_label_info_frame_rate_in->setText(QString::number(fps_in, 'f', 2));
@@ -1085,8 +1170,8 @@ void PageRecord::OnUpdateInformation() {
 		m_label_info_size_in->setText(ReadableWidthHeight(m_video_in_width, m_video_in_height));
 		m_label_info_size_out->setText(ReadableWidthHeight(m_output_settings.video_width, m_output_settings.video_height));
 		m_label_info_file_name->setText(file_name);
-		m_label_info_file_size->setText(ReadableSize(total_bytes, "B"));
-		m_label_info_bit_rate->setText(ReadableSize(bit_rate, "bps"));
+		m_label_info_file_size->setText(ReadableSizeIEC(total_bytes, "B"));
+		m_label_info_bit_rate->setText(ReadableSizeSI(bit_rate, "bit/s"));
 
 		if(!g_option_statsfile.isNull()) {
 			QString str = QString() +
@@ -1137,6 +1222,7 @@ void PageRecord::OnUpdateInformation() {
 
 void PageRecord::OnNewLogLine(Logger::enum_type type, QString string) {
 
+#if SSR_USE_ALSA
 	// play sound for errors
 	//TODO// this is an ugly way to detect errors, this should be improved at some point
 	int64_t time = hrt_time_micro();
@@ -1144,7 +1230,10 @@ void PageRecord::OnNewLogLine(Logger::enum_type type, QString string) {
 		m_simple_synth->PlaySequence(SEQUENCE_RECORD_ERROR.data(), SEQUENCE_RECORD_ERROR.size());
 		m_last_error_sound = time;
 	}
-	if(m_page_started && type == Logger::TYPE_ERROR) {
+#endif
+
+	// change system tray icon if an error has occurred
+	if(m_page_started && type == Logger::TYPE_ERROR && !m_error_occurred) {
 		m_error_occurred = true;
 		UpdateSysTray();
 	}
