@@ -96,8 +96,10 @@ extern "C" {
 #include <libavformat/avformat.h>
 #include <libavcodec/avcodec.h>
 #include <libavutil/avutil.h>
+#include <libavutil/channel_layout.h>
 #include <libavutil/mathematics.h>
 #include <libavutil/pixfmt.h>
+#include <libavutil/samplefmt.h>
 #include <libswscale/swscale.h>
 }
 
@@ -169,6 +171,8 @@ inline void atomic_thread_fence_replacement(memory_order) {
 #define TEST_AV_VERSION(prefix, ffmpeg_major, ffmpeg_minor, libav_major, libav_minor) TEST_MAJOR_MINOR(prefix##_VERSION_MAJOR, prefix##_VERSION_MINOR, libav_major, libav_minor)
 #endif
 
+// av_register_all deprecated: lavf 58.9.100 / ???
+#define SSR_USE_AV_REGISTER_ALL_DEPRECATED         TEST_AV_VERSION(LIBAVFORMAT, 58, 9, 999, 999)
 // AVStream::codecpar: lavf 57.33.100 / 57.5.0
 #define SSR_USE_AVSTREAM_CODECPAR                  TEST_AV_VERSION(LIBAVFORMAT, 57, 33, 57, 5)
 // AVStream::time_base as time base hint: lavf 55.44.100 / 55.20.0
@@ -182,10 +186,15 @@ inline void atomic_thread_fence_replacement(memory_order) {
 // avformat_free_context: lavf 52.96.0 / 52.96.0
 #define SSR_USE_AVFORMAT_FREE_CONTEXT              TEST_AV_VERSION(LIBAVFORMAT, 52, 96, 52, 96)
 
+// av_lockmgr_register deprecated: lavc 58.9.100 / ???
+#define SSR_USE_AV_LOCKMGR_REGISTER_DEPRECATED     TEST_AV_VERSION(LIBAVCODEC, 58, 9, 999, 999)
 // avcodec_send_packet, avcodec_receive_frame, avcodec_send_frame, avcodec_receive_packet: lavc 57.37.100 / ???
 #define SSR_USE_AVCODEC_SEND_RECEIVE               TEST_AV_VERSION(LIBAVCODEC, 57, 37, 999, 999)
 // av_packet_alloc: lavc 57.12.100 / 57.8.0
 #define SSR_USE_AV_PACKET_ALLOC                    TEST_AV_VERSION(LIBAVCODEC, 57, 12, 57, 8)
+// AV_CODEC_CAP_*, AV_CODEC_FLAG_*: lavc 56.56.100 / 56.35.0
+#define SSR_USE_AV_CODEC_CAP                       TEST_AV_VERSION(LIBAVCODEC, 56, 56, 56, 35)
+#define SSR_USE_AV_CODEC_FLAG                      TEST_AV_VERSION(LIBAVCODEC, 56, 56, 56, 35)
 // av_packet_rescale_ts: lavc 55.68.100 / 55.55.0
 #define SSR_USE_AV_PACKET_RESCALE_TS               TEST_AV_VERSION(LIBAVCODEC, 55, 68, 55, 55)
 // AVCodecContext::side_data_only_packets added: lavc 55.66.100 / 55.54.0
@@ -266,12 +275,14 @@ public:
 		return "SSRStreamException";
 	}
 };
+#if SSR_USE_ALSA
 class ALSAException : public std::exception {
 public:
 	inline virtual const char* what() const throw() override {
 		return "ALSAException";
 	}
 };
+#endif
 #if SSR_USE_PULSEAUDIO
 class PulseAudioException : public std::exception {
 public:
@@ -280,12 +291,14 @@ public:
 	}
 };
 #endif
+#if SSR_USE_JACK
 class JACKException : public std::exception {
 public:
 	inline virtual const char* what() const throw() override {
 		return "JACKException";
 	}
 };
+#endif
 
 // simple function to do 16-byte alignment
 inline size_t grow_align16(size_t size) {
