@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2012-2016 Maarten Baert <maarten-baert@hotmail.com>
+Copyright (c) 2012-2017 Maarten Baert <maarten-baert@hotmail.com>
 
 This file is part of SimpleScreenRecorder.
 
@@ -30,5 +30,5 @@ QString GetApplicationSystemDir(const QString& subdir = QString());
 QString GetApplicationUserDir(const QString& subdir = QString());
 QString GetVersionInfo();
 
-bool NVidiaDetectFlipping();
+bool NVidiaGetFlipping();
 bool NVidiaDisableFlipping();
