@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2012-2016 Maarten Baert <maarten-baert@hotmail.com>
+Copyright (c) 2012-2017 Maarten Baert <maarten-baert@hotmail.com>
 
 This file is part of SimpleScreenRecorder.
 
@@ -20,5 +20,5 @@ along with SimpleScreenRecorder.  If not, see <http://www.gnu.org/licenses/>.
 #pragma once
 #include "Global.h"
 
-bool NVidiaDetectFlipping();
-bool NVidiaDisableFlipping();
+bool NVidiaGetFlipping();
+bool NVidiaSetFlipping(bool enable);
